@@ -21,7 +21,7 @@ class DownloadError(RuntimeError):
 
 
 class InvalidIdError(RuntimeError):
-    """Error thrown when Entrez responds with a 4xx error."""
+    """Error thrown when Entrez responds with a 4xx error (other than 429)."""
 
     def __init__(self, message, ids, status_code):
         super().__init__(message)
@@ -29,6 +29,14 @@ class InvalidIdError(RuntimeError):
         self.status_code = status_code
 
 
+class TooManyRequests(DownloadError):
+    """Error thrown when Entrez responds with a 429 error."""
+
+    def __init__(self, message, retry_after):
+        super().__init__(message)
+        self.retry_after = retry_after
+
+
 class BadPatternError(DownloadError):
     """Error thrown when download file contains an error pattern."""
 
